@@ -10,7 +10,8 @@ typedef struct {
 } hash_context;
 
 void hash_initial( hash_context * c );
-void hash_process( hash_context * c, unsigned char * data, unsigned len );
-void hash_final( hash_context * c, uint32[HW] );
+void hash_process( hash_context * c, unsigned char * data, unsigned len,
+                   bool handsoff);
+void hash_final( hash_context * c, uint32[HW], bool handsoff);
 
-#endif
\ No newline at end of file
+#endif
